#
#
#
#
# check number of args we got from controller
if [ $# -lt 3 ]
then
logger -t exacqVision -- Invalid number of args. Got: $#
exit
fi

## args are passed in from the controller.  "flash install directory" "sd mount point" "sd install dir"
## default is /var/apps/exacqvision
PKGDIR="$1"

# default is /home/httpd/sdcard"
MNT_POINT="$2"

# default install directory is /apps/exacqvision
## which makes the /home/httpd/sdcard/apps/exacqvision
INSTALL_DIR=$MNT_POINT/"$3"

## default is /var/apps/exacqvision
PKGDIR="$1"

logger -t exacqVision "Install to " $PKGDIR $INSTALL_DIR $MNT_POINT

#
#  see if we need to go through the whole uptar/copy/install process
NEED_UPDATE="0"

# these are the old tests.  Still necessary but not sufficient
# if install directory doesn't exist or core not there 
if [ ! -e $INSTALL_DIR -o ! -e $PKGDIR/core ]
then
  logger -t exacqVision -- "Can't find installation. Creating installation files"
  NEED_UPDATE="1"
fi

#  if we don't have md5 info for the install files, we better be safe
if [ ! -e $PKGDIR/oldmd5.dat ]
then
  logger -t exacqVision -- "Can't find MD5 info. Creating installation files"
  NEED_UPDATE="1"
else

  # we have old md5 info.  generate new value and compare
  NEW_MD5=`md5sum $PKGDIR/install/edvrserver-arm-isd-install.tar.lzma | cut -d ' ' -f1`

  source ./oldmd5.dat

  if [ "$NEW_MD5" != "$OLD_MD5" ]
  then
    logger -t exacqVision -- "MD5 has changed. Creating installation files" $NEW_MD5 $OLD_MD5
    NEED_UPDATE="1"
  else
    logger -t exacqVision -- "MD5 has not changed." $NEW_MD5 $OLD_MD5
  fi
fi

if [ "$NEED_UPDATE" -ne "0" ]
then
  logger -t exacqVision -- "Start install"
  killall ExacqVision
  sleep 5
  cd $PKGDIR
  mkdir -p $INSTALL_DIR
  mkdir -p $INSTALL_DIR/logs 
  mkdir -p $INSTALL_DIR/audit
  mkdir -p $INSTALL_DIR/blob
  mkdir -p $INSTALL_DIR/edvr
  mkdir -p $INSTALL_DIR/posdata
  mkdir -p $INSTALL_DIR/downloads
  mkdir -p $INSTALL_DIR/edvr/0
  mkdir -p $INSTALL_DIR/data
  rm -rf $INSTALL_DIR/plugins
  rm -rf $INSTALL_DIR/lib
  rm core
  rm $INSTALL_DIR/core
  cp -r install/edvrserver-arm-isd-install.tar.lzma $INSTALL_DIR
  export LD_LIBRARY_PATH=`pwd`/install
  cd $INSTALL_DIR
  lzma -d edvrserver-arm-isd-install.tar.lzma
  tar -xf edvrserver-arm-isd-install.tar
  logger -t exacqVision -- "Done expanding tarred installation files"
  mv -f exacq/* .
  rm edvrserver-arm-isd-install.tar
  cp core $PKGDIR
  chmod +x $PKGDIR/core
  cp sendEmail.pl $PKGDIR
  chmod +x $PKGDIR/sendEmail.pl
 #
#  Don't overwrite existing xml
#  Busybox shell cp command doesn't support -n so do it the hard way
  for fil in `ls *.xml`
  do 
    if [ ! -e $PKGDIR/$fil ]
    then
      cp $fil $PKGDIR
    fi
  done
  mv zones.txt $PKGDIR
  cd $PKGDIR
  mkdir -p lib
  cd lib
  rm *
  logger -t exacqVision -- "creating library links"
  pwd | logger -t exacqVision 
  chmod +x ../install/create_links.sh
  source ../install/create_links.sh
  cd ..
  ln -s $INSTALL_DIR/plugins plugins
  ln -s $INSTALL_DIR/logs logs
  ln -s $INSTALL_DIR/audit audit
  ln -s $INSTALL_DIR/blob blob
  ln -s $INSTALL_DIR/downloads downloads
  ln -s $INSTALL_DIR/curl curl
  ln -s $INSTALL_DIR/lshw lshw
  ln -s $INSTALL_DIR/update update
  ln -s $INSTALL_DIR/update_daemon update_daemon
  ln -s $INSTALL_DIR/downloads downloads
  ln -s $INSTALL_DIR/update update
  ln -s $INSTALL_DIR/update_daemon update_daemon
  ln -s $INSTALL_DIR/data data
  mkdir -p edvr
  cd edvr
  ln -s $INSTALL_DIR/edvr/0 0
  if [ -e /tmp/mmcblk1p1 ]
  then
     ln -s /tmp/mmcblk1p1 1
     logger -t exacqVision -- "Creating link for 2nd SD card"
  fi
  cd ..
# remove or mv renamed copies of event DB
  for fil in `ls eventpi.db.*`
  do
      if [ -L $fil ]
      then
	  rm $fil
      else
	  mv $fil $INSTALL_DIR
      fi
  done

  logger -t exacqVision -- "All runtime files created"
  echo export OLD_MD5=`md5sum $PKGDIR/install/edvrserver-arm-isd-install.tar.lzma | cut -d ' ' -f1` >oldmd5.dat
  ./ExacqVision -i $1 -m $2 -s $3 &
else
  logger -t exacqVision - "Runtime files are already installed"
  cd $PKGDIR
# if pos or event database exists on flash, copy to SD & create link
  if [ -e pospi.db -a ! -L pospi.db ]
  then
      mv pospi.db $INSTALL_DIR/posdata
  elif [ -e pospi.db ]
  then
      rm -f pospi.db
  fi
  ln -s $INSTALL_DIR/posdata/pospi.db pospi.db

  if [ -e eventpi.db -a ! -L eventpi.db ]
  then
      mv eventpi.db $INSTALL_DIR
  elif [ -e eventpi.db ]
  then
      rm -f eventpi.db
  fi
  ln -s $INSTALL_DIR/eventpi.db eventpi.db

# now do the same for the wal/shm files, but don't create links
  if [ -e eventpi.db-shm -a ! -L eventpi.db-shm ]
  then
      mv eventpi.db-shm $INSTALL_DIR
  elif [ -e eventpi.db ]
  then
      rm -f eventpi.db-shm
  fi

  if [ -e eventpi.db-wal -a ! -L eventpi.db-wal ]
  then
      mv eventpi.db-wal $INSTALL_DIR
  elif [ -e eventpi.db ]
  then
      rm -f eventpi.db-wal
  fi

  if [ -e pospi.db-shm -a ! -L pospi.db-shm ]
  then
      mv pospi.db-shm $INSTALL_DIR/posdata
  elif [ -e pospi.db ]
  then
      rm -f pospi.db-shm
  fi

  if [ -e pospi.db-wal -a ! -L pospi.db-wal ]
  then
      mv pospi.db-wal $INSTALL_DIR/posdata
  elif [ -e pospi.db ]
  then
      rm -f pospi.db-wal
  fi
fi
